AlertAction class

Alert action definition.

Constructors

AlertAction({required AlertActionType type, Map<String, dynamic> config = const {}, Duration? delay, Duration? repeatInterval})
const

Properties

config Map<String, dynamic>
Action configuration.
final
delay Duration?
Delay before executing action.
final
hashCode int
The hash code for this object.
no setterinherited
repeatInterval Duration?
Interval between repeated actions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AlertActionType
Action type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited