Artifact class

Generated artifact from skill execution.

Constructors

Artifact({required String id, required String type, required dynamic content, String? mimeType, String? fileName, Map<String, dynamic>? metadata})
const
Artifact.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

content → dynamic
Content (could be string, bytes ref, etc).
final
fileName String?
File name.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Artifact ID.
final
metadata Map<String, dynamic>?
Metadata.
final
mimeType String?
MIME type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Artifact type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited