AutomationQuery class

Query for automations.

Constructors

AutomationQuery({String? workspaceId, AutomationTriggerType? triggerType, bool? enabled, int? limit})
const

Properties

enabled bool?
Filter by enabled.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Limit results.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerType AutomationTriggerType?
Filter by trigger type.
final
workspaceId String?
Filter by workspace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited