BundleValidationError class

A single validation error or warning.

Constructors

BundleValidationError({required String code, required String message, String? path, BundleValidationSeverity severity = BundleValidationSeverity.error})
const

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity BundleValidationSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited