CachingAppraisalEnginePort class

AppraisalEnginePort decorator that adds caching.

Implemented types

Constructors

CachingAppraisalEnginePort(AppraisalEnginePort _delegate, MetricCachingService _cache, [AppraisalCacheConfig _config = const AppraisalCacheConfig()])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeAggregate(Map<String, MetricComputeResult> metrics, AggregationConfig? config) Future<double>
Reduce compute results into a single aggregated score.
override
computeMetrics(List<AppraisalMetricDef> metrics, ProfileContext context) Future<Map<String, MetricComputeResult>>
Compute metrics based on definitions and context.
override
getHistory(String profileId, Period period) Future<List<AppraisalResult>>
Historical appraisal results.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited