CandidateField class

A field in a candidate with value and confidence.

Constructors

CandidateField({required dynamic value, required double confidence, String? sourceFragmentId, bool confirmed = false})
const
CandidateField.fromJson(Map<String, dynamic> json)
factory

Properties

confidence double
Confidence score.
final
confirmed bool
Whether this field is confirmed.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceFragmentId String?
Source fragment ID.
final
value → dynamic
Field value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited