CheckpointRestoredEvent class

Emitted when a checkpoint is restored during recovery.

Inheritance

Constructors

CheckpointRestoredEvent({required String executionId, required String checkpointId, required String eventId, required String correlationId, required String runId, required String workspaceId, required DateTime timestamp, required OpsEventMeta meta, String version = '1.0', String? causationId})
CheckpointRestoredEvent.create({required String executionId, required String checkpointId, required String correlationId, String? causationId, required String runId, required String workspaceId, required OpsEventMeta meta})
Convenience factory with auto-generated ID and timestamp.
factory

Properties

causationId String?
Causation ID pointing to the event that caused this one.
finalinherited
checkpointId String
Checkpoint identifier that was restored.
final
correlationId String
Correlation ID linking related events across a workflow.
finalinherited
eventId String
Unique event identifier (UUID-like).
finalinherited
eventType String
Fully qualified event type (e.g. 'ops.pipeline.started').
finalinherited
executionId String
Execution identifier.
final
hashCode int
The hash code for this object.
no setterinherited
meta OpsEventMeta
Event metadata for tracing and provenance.
finalinherited
payload Map<String, dynamic>
Event payload data.
finalinherited
runId String
Execution run ID.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Event timestamp.
finalinherited
version String
Event schema version for forward compatibility.
finalinherited
workspaceId String
Workspace scope.
finalinherited

Methods

copyWith({String? eventId, String? eventType, String? version, String? correlationId, String? causationId, String? runId, String? workspaceId, DateTime? timestamp, Map<String, dynamic>? payload, OpsEventMeta? meta}) OpsEvent
Create a copy with updated fields.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON map.
inherited
toPortEvent() PortEvent
Convert this ops event to a PortEvent for transport via EventPort.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited