CircuitOpenException class

Exception thrown when circuit breaker is open.

Implemented types

Constructors

CircuitOpenException({required String message, required DateTime openedAt, required DateTime resetAt, required String circuitName})
const

Properties

circuitName String
The circuit breaker name.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message.
final
openedAt DateTime
When the circuit was opened.
final
remainingTime Duration
Remaining time until reset attempt.
no setter
resetAt DateTime
When the circuit will attempt reset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited