ClassifierMemoryQuery class

Query for classifier memories.

Constructors

ClassifierMemoryQuery({String? workspaceId, String? taxonomyId, String? categoryId, MemorySource? source, double? minConfidence, int? limit})
const

Properties

categoryId String?
Filter by category ID.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Limit results.
final
minConfidence double?
Filter by minimum confidence.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source MemorySource?
Filter by source.
final
taxonomyId String?
Filter by taxonomy ID.
final
workspaceId String?
Filter by workspace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited