CompensationFailure class

Record of a compensation failure for a specific stage.

Constructors

CompensationFailure({required String stageId, required String error, required int attemptCount})
const

Properties

attemptCount int
Number of compensation attempts made.
final
error String
Error message.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stageId String
Stage identifier that failed compensation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited