ConflictPath class

A path showing how a conflict arose.

Constructors

ConflictPath({required List<PackageRef> path, required VersionConstraint constraint})
const

Properties

constraint → VersionConstraint
The conflicting constraint.
final
hashCode int
The hash code for this object.
no setterinherited
path List<PackageRef>
Packages in the path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited