CurationOutput class

Output of curation pipeline.

Constructors

CurationOutput({required int processed, required int confirmedCount, required int rejectedCount, required int deferredCount, required int merged, List<String> confirmedIds = const [], List<String> rejectedIds = const []})
const

Properties

confirmedCount int
final
confirmedIds List<String>
final
deferredCount int
final
hashCode int
The hash code for this object.
no setterinherited
merged int
final
processed int
final
rejectedCount int
final
rejectedIds List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited