DateTimeRange class
A time range with start and end.
Constructors
- DateTimeRange({required DateTime start, required DateTime end})
-
const
Properties
- duration → Duration
-
Duration of the range.
no setter
- end → DateTime
-
End of the range (exclusive).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
Start of the range (inclusive).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited