DecisionPolicySection class
Section containing decision policies.
Constructors
-
DecisionPolicySection({required List<
DecisionPolicy> policies, String? defaultPolicy, ConflictResolution conflictResolution = ConflictResolution.firstMatch}) -
const
-
DecisionPolicySection.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conflictResolution → ConflictResolution
-
Conflict resolution strategy.
final
- defaultPolicy → String?
-
Default policy ID for fallback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
policies
→ List<
DecisionPolicy> -
Policies in evaluation order (sorted by priority).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortedPolicies
→ List<
DecisionPolicy> -
Get sorted policies by priority (higher first).
no setter
Methods
-
getPolicy(
String id) → DecisionPolicy? - Get policy by ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited