DocumentationExtractor class

Documentation extractor.

Inheritance

Constructors

DocumentationExtractor(String dimensionId)

Properties

dimensionId String
Dimension ID this extractor targets.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extract(Artifact artifact, ExtractorConfig config) Future<DimensionMeasurement>
Extract measurement from artifact.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited