EntityStoragePort class abstract

Port for entity storage operations.

Constructors

EntityStoragePort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteEntity(String entityId) Future<void>
Delete entity.
findByName(String query) Future<List<Entity>>
Find entities by name.
getEntity(String entityId) Future<Entity?>
Get entity by ID.
getRelated(String entityId) Future<List<Entity>>
Get related entities.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryEntities(EntityQuery query) Future<List<Entity>>
Query entities.
saveEntity(Entity entity) Future<void>
Store entity.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited