EvaluationConfig class

Configuration for skill evaluation.

Constructors

EvaluationConfig({List<String>? evalSets, double? minPassRate, bool? regressionCheck, bool? benchmarkCheck})
const

Properties

benchmarkCheck bool?
Whether to run benchmark checks.
final
evalSets List<String>?
Evaluation set identifiers to run.
final
hashCode int
The hash code for this object.
no setterinherited
minPassRate double?
Minimum pass rate required (0.0 - 1.0).
final
regressionCheck bool?
Whether to run regression checks.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited