EventReplayer class

Replays persisted events for execution recovery and debugging.

Events are read from KvStoragePort using the key conventions defined in EventStorageKeys and EventStreams, then routed through the EventRouter (or simulated in dry-run mode).

Constructors

EventReplayer({required KvStoragePort kvStorage, required EventRouter router, required ExecutionLogger logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replayExecution(String executionId, {int? fromPosition, DateTime? fromTimestamp, DateTime? toTimestamp, bool dryRun = false}) Future<ReplayResult>
Replay all events for a specific execution.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited