EvidenceStoragePort class abstract
Port for evidence storage operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteEvidence(
String evidenceId) → Future< void> - Delete evidence.
-
getEvidence(
String evidenceId) → Future< Evidence?> - Get evidence by ID.
-
getFragments(
String evidenceId) → Future< List< Fragment> > - Get fragments for evidence.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryEvidence(
EvidenceQuery query) → Future< List< Evidence> > - Query evidence.
-
saveEvidence(
Evidence evidence) → Future< void> - Store evidence.
-
saveFragments(
List< Fragment> fragments) → Future<void> - Store fragments.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited