ExecutionEngineConfig class
Execution engine configuration.
Constructors
- ExecutionEngineConfig({ExecutionConfig executionDefaults = const ExecutionConfig(), int maxConcurrentExecutions = 4})
-
const
Properties
- executionDefaults → ExecutionConfig
-
Default execution configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrentExecutions → int
-
Maximum concurrent executions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited