ExecutionMetadata class

Execution metadata.

Constructors

ExecutionMetadata({required String skillId, required String skillVersion, required String procedureId, required DateTime startedAt, required DateTime finishedAt, required Duration duration, required int stepsExecuted, LlmUsage? llmUsage, required List<String> toolsCalled, Map<String, dynamic>? custom})
const
ExecutionMetadata.create({required String skillId, required String skillVersion, required String procedureId, required DateTime startedAt, DateTime? finishedAt, required int stepsExecuted, LlmUsage? llmUsage, List<String>? toolsCalled, Map<String, dynamic>? custom})
Create with computed duration.
factory
ExecutionMetadata.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

custom Map<String, dynamic>?
Custom metadata.
final
duration Duration
Total duration.
final
finishedAt DateTime
When execution finished.
final
hashCode int
The hash code for this object.
no setterinherited
llmUsage LlmUsage?
LLM usage statistics.
final
procedureId String
Procedure ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillId String
Skill ID.
final
skillVersion String
Skill version.
final
startedAt DateTime
When execution started.
final
stepsExecuted int
Number of steps executed.
final
toolsCalled List<String>
Tools called during execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited