FactClusterQuery class

Query for fact clusters.

Constructors

FactClusterQuery({String? workspaceId, String? factType, FactClusterStatus? status, double? minConfidence, int? limit})
const

Properties

factType String?
Filter by fact type.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Limit results.
final
minConfidence double?
Filter by minimum confidence.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status FactClusterStatus?
Filter by status.
final
workspaceId String?
Filter by workspace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited