FunctionHandler class

Function-based handler for simple cases.

Inheritance

Constructors

FunctionHandler({required String name, required Future handler(dynamic input, HandlerContext context)})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Handler identifier.
no setterinherited
inputSchema Map<String, dynamic>?
Input schema descriptor.
no setterinherited
name String
Handler name.
final
outputSchema Map<String, dynamic>?
Output schema descriptor.
no setterinherited
requires List<String>
Required port/capability names.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Handler version.
no setterinherited

Methods

cleanup() Future<void>
Cleanup resources after execution.
inherited
execute(dynamic input, HandlerContext context) Future
Execute the handler.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateInput(dynamic input) List<String>
Validate input before execution.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited