GateEvaluatedEvent class

Gate evaluated event.

Implemented types

Constructors

GateEvaluatedEvent({required DateTime timestamp, required String runId, required String pipelineId, required String gateId, required bool passed, required Map<String, bool> conditions})
const

Properties

conditions Map<String, bool>
Condition results summary.
final
gateId String
Gate identifier.
final
hashCode int
The hash code for this object.
no setterinherited
passed bool
Whether gate passed.
final
pipelineId String
Pipeline identifier.
final
runId String
Execution run ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Event timestamp.
final
type String
Event type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited