InMemoryEventPort class

In-memory event port for testing.

Implemented types

Constructors

InMemoryEventPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose the controller.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(PortEvent event) Future<void>
Publish an event.
override
subscribe(String eventType) Stream<PortEvent>
Subscribe to events of a type.
override
subscribeAll() Stream<PortEvent>
Subscribe to all events.
override
toString() String
A string representation of this object.
inherited
unsubscribe(String eventType) Future<void>
Unsubscribe from a type.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited