IngestConfig class

Configuration for the ingest pipeline.

Constructors

IngestConfig({int maxConcurrency = 1, Duration? timeout, RetryPolicy? retryPolicy, OnErrorStrategy onError = OnErrorStrategy.fail, bool checkpointEnabled = false, Map<String, dynamic> extra = const {}, bool autoPromote = true, double autoPromoteThreshold = 0.85, bool skipDuplicates = false, String fragmentExtractor = 'default', String entityLinkingStrategy = 'strict', Duration? duplicateCheckWindow})
const

Properties

autoPromote bool
final
autoPromoteThreshold double
final
checkpointEnabled bool
Whether checkpointing is enabled.
finalinherited
duplicateCheckWindow Duration?
final
entityLinkingStrategy String
final
extra Map<String, dynamic>
Additional configuration.
finalinherited
fragmentExtractor String
final
hashCode int
The hash code for this object.
no setterinherited
maxConcurrency int
Maximum concurrent executions.
finalinherited
onError OnErrorStrategy
Error handling strategy.
finalinherited
retryPolicy RetryPolicy?
Retry policy.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipDuplicates bool
final
timeout Duration?
Pipeline timeout.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited