IngestPipeline class

Pipeline for ingesting content into the fact graph.

Implemented types

Constructors

IngestPipeline({String? id, String name = 'Ingest Pipeline', String version = '1.0.0', String? description = 'Ingest raw content into the fact graph', IngestConfig? config})

Properties

config IngestConfig
Pipeline configuration.
final
description String?
Pipeline description.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Pipeline identifier.
final
name String
Pipeline name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stages List<PipelineStage>
Pipeline stages.
final
version String
Pipeline version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(IngestInput input, PipelineContext context) Future<PipelineResult<IngestOutput>>
Execute the pipeline.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited