LockVerificationIssue class

A verification issue.

Constructors

LockVerificationIssue({required LockVerificationIssueType type, required String packageName, required String message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Issue description.
final
packageName String
Package name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type LockVerificationIssueType
Issue type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited