PackageSpec class
Specification of a package's dependencies.
Constructors
-
PackageSpec({required String name, required SemanticVersion version, Map<
String, VersionConstraint> dependencies = const {}, Map<String, VersionConstraint> devDependencies = const {}}) -
const
Properties
-
dependencies
→ Map<
String, VersionConstraint> -
Dependencies.
final
-
devDependencies
→ Map<
String, VersionConstraint> -
Development dependencies.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Package name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → SemanticVersion
-
Package version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited