PipelineHandlerRegistry class

Registry for pipeline handlers.

Constructors

PipelineHandlerRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all handlers.
findByPattern(String pattern) List<PipelineHandler>
Find handlers by pattern.
get(String handlerId) PipelineHandler?
Get handler by ID.
has(String handlerId) bool
Check if handler exists.
list({HandlerFilter? filter}) List<HandlerInfo>
List all registered handlers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PipelineHandler handler) → void
Register a handler.
toString() String
A string representation of this object.
inherited
unregister(String handlerId) → void
Unregister a handler.
validate(String handlerId, {List<String>? required}) ValidationResult
Validate that a handler exists and optionally check required fields.

Operators

operator ==(Object other) bool
The equality operator.
inherited