ProfileMigration class

Describes a migration between two profile versions.

Constructors

ProfileMigration({required String fromVersion, required String toVersion, required Map<String, dynamic> transform(Map<String, dynamic>), bool breaking = false, String? notes, String? migrationScript})
const

Properties

breaking bool
Whether this is a breaking change.
final
fromVersion String
Source version.
final
hashCode int
The hash code for this object.
no setterinherited
migrationScript String?
Optional migration script identifier.
final
notes String?
Migration notes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toVersion String
Target version.
final
transform Map<String, dynamic> Function(Map<String, dynamic>)
Transform function (takes old data, returns new data).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited