ProfileRuntimeHook class abstract

Hook for runtime events per design/03-runtime.md 6.

Constructors

ProfileRuntimeHook()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String event, RuntimeProfileContext context, {AppraisalResult? appraisal, DecisionGuidance? decision}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited