ProhibitionViolatedEvent class

Prohibition violated event.

Implemented types

Constructors

ProhibitionViolatedEvent({required String prohibitionId, required String severity, required String detail, required bool isHard, required DateTime timestamp})
const

Properties

detail String
Violation detail.
final
hashCode int
The hash code for this object.
no setterinherited
isHard bool
Whether this is a hard (blocking) prohibition.
final
prohibitionId String
Prohibition identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String
Violation severity.
final
timestamp DateTime
Event timestamp.
final
type String
Event type identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited