ReinforcementPattern class

A detected reinforcement pattern from feedback history.

Annotations
  • @immutable

Constructors

ReinforcementPattern({required String componentId, required PatternDirection direction, required double strength, required int sampleSize, required double averageOutcomeScore})
const
ReinforcementPattern.fromJson(Map<String, dynamic> json)
factory

Properties

averageOutcomeScore double
Average outcome score.
final
componentId String
final
direction PatternDirection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleSize int
Number of feedback events.
final
strength double
Pattern strength (0.0-1.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited