ReviewRequestedEvent class

Review requested event.

Implemented types

Constructors

ReviewRequestedEvent({required DateTime timestamp, required String runId, required String stageId, required List<String> reviewers})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reviewers List<String>
Reviewers.
final
runId String
Execution run ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stageId String
Stage requiring review.
final
timestamp DateTime
Event timestamp.
final
type String
Event type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited