RubricScore class
Rubric score from evaluation.
Constructors
Properties
-
dimensionScores
→ Map<
String, double> -
Dimension scores.
final
-
findings
→ List<
Finding> ? -
Findings from evaluation.
final
- grade → String
-
Grade/classification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passed → bool
-
Check if evaluation passed.
no setter
- rubricId → String
-
Rubric ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalScore → double
-
Total/aggregate score.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited