RunbookCategory enum
Runbook category for classification.
Values
- dailyOperations → const RunbookCategory
-
Daily operational tasks.
- weeklyMaintenance → const RunbookCategory
-
Weekly maintenance tasks.
- incidentResponse → const RunbookCategory
-
Incident response procedures.
- deployment → const RunbookCategory
-
Deployment procedures.
- recovery → const RunbookCategory
-
Recovery procedures.
- scaling → const RunbookCategory
-
Scaling operations.
- security → const RunbookCategory
-
Security-related procedures.
- philosophyAlignment → const RunbookCategory
-
Philosophy alignment procedures.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RunbookCategory> - A constant List of the values in this enum, in order of their declaration.