ScheduleStatus enum

Status of a schedule.

Inheritance
Available extensions

Values

active → const ScheduleStatus

Schedule is active and will trigger normally.

paused → const ScheduleStatus

Schedule is paused (temporarily suspended).

disabled → const ScheduleStatus

Schedule is disabled (will not trigger).

deleted → const ScheduleStatus

Schedule has been permanently deleted.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScheduleStatus>
A constant List of the values in this enum, in order of their declaration.