SchedulerExecution class

Execution record managed by the scheduler.

Named SchedulerExecution to avoid conflict with execution_engine's Execution.

Constructors

SchedulerExecution({required String id, required String scheduleId, required String status, required TriggerInfo triggeredBy, required DateTime queuedAt, DateTime? startedAt, DateTime? completedAt, Map<String, dynamic>? input, ExecutionResult? result, ExecutionError? error, ExecutionMetrics? metrics})
const

Properties

completedAt DateTime?
When this execution completed.
final
error → ExecutionError?
Execution error (on failure).
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique execution identifier.
final
input Map<String, dynamic>?
Input data for the execution.
final
metrics ExecutionMetrics?
Execution performance metrics.
final
queuedAt DateTime
When this execution was queued.
final
result → ExecutionResult?
Execution result (on success).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleId String
Associated schedule identifier.
final
startedAt DateTime?
When this execution started running.
final
status String
Current execution status: 'queued', 'running', 'completed', 'failed', 'cancelled'.
final
triggeredBy → TriggerInfo
Information about the trigger that caused this execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited