SchedulerStatus class

Overall scheduler status.

Constructors

SchedulerStatus({int activeSchedules = 0, int pausedSchedules = 0, int pendingExecutions = 0, int runningExecutions = 0, DateTime? lastActivityAt})
const

Properties

activeSchedules int
Number of active schedules.
final
hashCode int
The hash code for this object.
no setterinherited
lastActivityAt DateTime?
Timestamp of last activity.
final
pausedSchedules int
Number of paused schedules.
final
pendingExecutions int
Number of pending executions in queue.
final
runningExecutions int
Number of currently running executions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited