SkillExecutedEvent class

Skill executed event.

Implemented types

Constructors

SkillExecutedEvent({required String skillId, required String executionId, required bool success, required Duration duration, int claimCount = 0, required DateTime timestamp})
const

Properties

claimCount int
Number of claims extracted.
final
duration Duration
Execution duration.
final
executionId String
Execution ID.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillId String
Skill ID.
final
success bool
Whether execution succeeded.
final
timestamp DateTime
Event timestamp.
final
type String
Event type identifier.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited