SkillRegistryPort class abstract

Port for skill bundle registry.

Constructors

SkillRegistryPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBundle(String id) Future<BundleDescriptor?>
Get a bundle descriptor by ID.
listBundles() Future<List<BundleDescriptor>>
List all registered bundles.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerBundle(BundleDescriptor descriptor) Future<void>
Register a bundle by manifest payload.
toString() String
A string representation of this object.
inherited
unregister(String id) Future<void>
Unregister a bundle.

Operators

operator ==(Object other) bool
The equality operator.
inherited