StageSkippedEvent class

Stage skipped event.

Implemented types

Constructors

StageSkippedEvent({required DateTime timestamp, required String runId, required String pipelineId, required String stageId, required String reason})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pipelineId String
Pipeline identifier.
final
reason String
Reason for skipping.
final
runId String
Execution run ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stageId String
Stage identifier.
final
timestamp DateTime
Event timestamp.
final
type String
Event type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited