StandardPolicies class
Standard decision policies as per 7.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
all(
) → List< DecisionPolicy> - Get all standard policies.
-
criticalRiskReject(
{int priority = 100}) → DecisionPolicy - Critical risk reject policy (7.1).
-
highRiskEscalate(
{int priority = 90}) → DecisionPolicy - High risk escalate policy (7.1).
-
highUncertaintyQuestion(
{int priority = 80}) → DecisionPolicy - High uncertainty question policy (7.2).
-
moderateRiskCaution(
{int priority = 50}) → DecisionPolicy - Moderate risk caution policy (7.1).
-
riskBasedPolicies(
) → List< DecisionPolicy> - Get all standard risk-based policies.
-
uncertaintyBasedPolicies(
) → List< DecisionPolicy> - Get all standard uncertainty-based policies.