Step class

A step in a procedure execution flow.

Constructors

Step({required String id, required int order, required String name, String? description, required StepAction action, String? condition, String? onSuccess, String? onFailure, RetryConfig? retryConfig, int? timeout})
const
Step.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

action StepAction
Action configuration.
final
condition String?
Condition expression for conditional execution.
final
description String?
Step description.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Step identifier (unique within procedure).
final
name String
Step name.
final
onFailure String?
Next step ID on failure.
final
onSuccess String?
Next step ID on success.
final
order int
Execution order.
final
retryConfig → RetryConfig?
Retry configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
Timeout in milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited