SummaryPeriod class

Simple period for summary time range.

Constructors

SummaryPeriod({required DateTime start, required DateTime end})
const
SummaryPeriod.fromJson(Map<String, dynamic> json)
factory

Properties

duration Duration
Duration of the period.
no setter
end DateTime
Period end.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
Period start.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited