SummaryStatus enum
Summary status. Reference: Design Section 2.15.1 - created | active | stale | refreshFail | archived
Values
- created → const SummaryStatus
-
Newly created, generation pending.
- active → const SummaryStatus
-
Current and valid.
- stale → const SummaryStatus
-
Source data changed, refresh needed.
- refreshFail → const SummaryStatus
-
Refresh attempted but failed.
- archived → const SummaryStatus
-
No longer maintained.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → SummaryStatus
Constants
-
values
→ const List<
SummaryStatus> - A constant List of the values in this enum, in order of their declaration.