TemplateVariable class

A template variable within section content.

Constructors

TemplateVariable({required String name, String type = 'string', dynamic defaultValue, bool required = true, String? description})
const
TemplateVariable.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → dynamic
Default value.
final
description String?
Variable description.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Variable name.
final
required bool
Whether the variable is required.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Variable type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited