TracingHook class

Tracing hook - adds distributed tracing support.

Inheritance

Constructors

TracingHook({required void recordSpan(String traceId, String spanId, String name, Map<String, dynamic> tags)})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterExecution(SkillContext context, SkillResult result) Future<void>
Called after skill execution completes.
inherited
beforeExecution(SkillContext context) Future<void>
Called before skill execution starts.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBudgetCheck(SkillContext context, BudgetCheckResult result) Future<void>
Called when budget is checked.
inherited
onClaimsExtracted(SkillContext context, List claims) Future<void>
Called when claims are extracted.
inherited
onContextBuilding(SkillContext context) Future<void>
Called when context building phase starts.
inherited
onError(SkillContext context, Object error, StackTrace stackTrace) Future<void>
Called when an error occurs.
inherited
onExecutionStart(SkillContext context) Future<void>
Called when execution phase starts.
inherited
onPersistence(SkillContext context) Future<void>
Called when persistence phase starts.
inherited
onPlanning(SkillContext context, List<String> skillIds) Future<void>
Called when planning phase starts.
inherited
onRouting(SkillContext context) Future<void>
Called when routing phase starts.
inherited
onStepComplete(SkillContext context, String stepId, Map<String, dynamic> output) Future<void>
Called when a step completes.
inherited
onStepFailure(SkillContext context, String stepId, Object error) Future<void>
Called when a step fails.
inherited
onStepStart(SkillContext context, String stepId, Map<String, dynamic> inputs) Future<void>
Called when a step starts executing.
override
onValidation(SkillContext context) Future<void>
Called when validation phase starts.
inherited
onWarning(SkillContext context, String message) Future<void>
Called for non-fatal warnings.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited