ValidatedCandidate class

Validated candidate with re-evaluated confidence.

Constructors

ValidatedCandidate({required String candidateId, required bool isValid, double newConfidence = 0.0, List<String> validationErrors = const []})
const

Properties

candidateId String
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
newConfidence double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validationErrors List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited