ValidationResult class

Validation result.

Constructors

ValidationResult({required bool valid, List<String> errors = const [], List<String> warnings = const []})
const
ValidationResult.invalid(List<String> errors)
factory
ValidationResult.valid()
factory

Properties

errors List<String>
Validation errors.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valid bool
Whether validation passed.
final
warnings List<String>
Validation warnings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited