VersionedProfileRegistry class

Versioned profile registry.

Constructors

VersionedProfileRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
ids List<String>
Get all profile IDs.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all profiles.
get(String id, {String? version}) Profile?
Get a specific version.
getLatest(String id) Profile?
Get the latest version.
getVersions(String id) List<String>
Get all versions of a profile.
has(String id, {String? version}) bool
Check if a profile exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Profile profile) → void
Register a profile version.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited