WorkflowConfig class

Workflow configuration.

Constructors

WorkflowConfig({Duration? timeout, bool autoApprove = false, bool dryRun = false, bool publishOnSuccess = false})
const

Properties

autoApprove bool
Whether to auto-approve review/approval stages.
final
dryRun bool
Whether to run in dry-run mode (no side effects).
final
hashCode int
The hash code for this object.
no setterinherited
publishOnSuccess bool
Whether to publish artifacts on successful completion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
Overall workflow timeout.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited