WorkflowStartedEvent class

Emitted when a workflow execution begins.

Inheritance

Constructors

WorkflowStartedEvent({required String workflowId, Map<String, dynamic>? input, String? workflowName, String? workflowVersion, List<String>? steps, List<String>? gates, required String eventId, required String correlationId, required String runId, required String workspaceId, required DateTime timestamp, required OpsEventMeta meta, String version = '1.0', String? causationId})
WorkflowStartedEvent.create({required String workflowId, Map<String, dynamic>? input, String? workflowName, String? workflowVersion, List<String>? steps, List<String>? gates, required String correlationId, String? causationId, required String runId, required String workspaceId, required OpsEventMeta meta})
Convenience factory with auto-generated ID and timestamp.
factory

Properties

causationId String?
Causation ID pointing to the event that caused this one.
finalinherited
correlationId String
Correlation ID linking related events across a workflow.
finalinherited
eventId String
Unique event identifier (UUID-like).
finalinherited
eventType String
Fully qualified event type (e.g. 'ops.pipeline.started').
finalinherited
gates List<String>?
List of gate identifiers in the workflow.
final
hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>?
Optional input data for the workflow.
final
meta OpsEventMeta
Event metadata for tracing and provenance.
finalinherited
payload Map<String, dynamic>
Event payload data.
finalinherited
runId String
Execution run ID.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<String>?
Ordered list of step identifiers in the workflow.
final
timestamp DateTime
Event timestamp.
finalinherited
version String
Event schema version for forward compatibility.
finalinherited
workflowId String
Workflow identifier.
final
workflowName String?
Human-readable workflow name.
final
workflowVersion String?
Workflow version string.
final
workspaceId String
Workspace scope.
finalinherited

Methods

copyWith({String? eventId, String? eventType, String? version, String? correlationId, String? causationId, String? runId, String? workspaceId, DateTime? timestamp, Map<String, dynamic>? payload, OpsEventMeta? meta}) OpsEvent
Create a copy with updated fields.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to JSON map.
inherited
toPortEvent() PortEvent
Convert this ops event to a PortEvent for transport via EventPort.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited