AlertCondition class
Alert condition definition.
Constructors
- AlertCondition({required AlertConditionType type, String? metric, String? operator, double? threshold, String? aggregation, Duration? window, String? logQuery, int? countThreshold, String? expression})
-
const
Properties
- aggregation → String?
-
Aggregation function (e.g. 'avg', 'sum', 'max', 'min', 'count').
final
- countThreshold → int?
-
Count threshold (for log conditions).
final
- expression → String?
-
Expression string (for expression conditions).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logQuery → String?
-
Log query string (for log conditions).
final
- metric → String?
-
Metric name (for metric conditions).
final
- operator → String?
-
Comparison operator (e.g. '>', '<', '>=', '<=', '==', '!=').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold → double?
-
Threshold value (for metric conditions).
final
- type → AlertConditionType
-
Condition type.
final
- window → Duration?
-
Time window for aggregation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited