AuditActor class
Actor who performed the audited operation.
Constructors
- AuditActor({required ActorType type, required String id, String? name, String? ip, String? userAgent})
-
const
-
AuditActor.fromJson(Map<
String, dynamic> json) -
Deserialize from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Actor identifier.
final
- ip → String?
-
IP address of the actor.
final
- name → String?
-
Human-readable name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ActorType
-
Actor type.
final
- userAgent → String?
-
User agent string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited