CachedGraphStorage class
Cached graph storage wrapper.
- Implemented types
Constructors
- CachedGraphStorage(GraphStorage _baseStorage, {int maxCacheSize = 100})
Properties
- cacheSize → int
-
Get current cache size.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCacheSize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCache(
) → void - Clear the cache.
-
delete(
String id) → Future< bool> -
Delete a graph.
override
-
exists(
String id) → Future< bool> -
Check if a graph exists.
override
-
listIds(
) → Future< List< String> > -
List all graph IDs.
override
-
load(
String id) → Future< FactGraph?> -
Load a graph by ID.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
FactGraph graph) → Future< void> -
Save a graph.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited