CancellationRequest class
Request to cancel a running workflow.
Constructors
- CancellationRequest({required String workflowId, required String executionId, required CancellationReason reason, String? requestedBy, required DateTime requestedAt})
-
const
Properties
- executionId → String
-
Execution identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → CancellationReason
-
Reason for cancellation.
final
- requestedAt → DateTime
-
When the cancellation was requested.
final
- requestedBy → String?
-
User who requested the cancellation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workflowId → String
-
Workflow identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited