ClaimFeatures class
Features extracted from a claim for pattern mining. Reference: Design Section 2.15.3.2 - ClaimFeatures.
Constructors
-
ClaimFeatures({required String claimType, required String domain, required String structuralPattern, List<
String> factTypes = const [], Map<String, dynamic> responseContext = const {}, ValidationOutcome outcome = const ValidationOutcome(isValid: false)}) -
const
-
ClaimFeatures.fromJson(Map<
String, dynamic> json) -
factory
Properties
- claimType → String
-
Type of the claim (aligned with ClaimType).
final
- domain → String
-
Domain of the claim.
final
-
factTypes
→ List<
String> -
Fact types referenced.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outcome → ValidationOutcome
-
Validation outcome details.
final
-
responseContext
→ Map<
String, dynamic> -
Response context where claim appeared.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuralPattern → String
-
Structural pattern (e.g., "X causes Y").
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited