ClaimQuery class
Query descriptor for ClaimsPort.queryClaims.
Constructors
-
ClaimQuery({required String workspaceId, List<
ClaimStatus> ? statuses, List<String> ? types, Period? period, String? entityId, int? limit}) -
const
Properties
- entityId → String?
-
Entity filter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum results.
final
- period → Period?
-
Period filter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statuses
→ List<
ClaimStatus> ? -
Claim status filter.
final
-
types
→ List<
String> ? -
Claim type filter.
final
- workspaceId → String
-
Workspace identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited