ContextEntity class
Entity from context.
Constructors
-
ContextEntity({required String id, required String type, required String name, Map<
String, dynamic> attributes = const {}}) -
const
-
ContextEntity.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
attributes
→ Map<
String, dynamic> -
Entity attributes.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Entity ID.
final
- name → String
-
Entity name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Entity type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override