ContextService class
Service for L2 ContextOps Layer operations.
Constructors
- ContextService({required ContextStoragePort storage, required FactStoragePort factStorage, LlmPort? llm, ClaimVerificationPort? verifier})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildContext(
{required String workspaceId, required String query, int tokenBudget = 4096}) → Future< InternalContextBundle> - Build context bundle for a query.
-
createSummary(
{required String workspaceId, required List< String> factIds, required SummaryScope scope}) → Future<SummaryNode> - Create summary from facts.
-
getClaim(
String claimId) → Future< VerifiableClaim?> - Get claim by ID.
-
getContextBundle(
String bundleId) → Future< InternalContextBundle?> - Get context bundle by ID.
-
getPendingClaims(
) → Future< List< VerifiableClaim> > - Get pending claims.
-
getSummaryNode(
String nodeId) → Future< SummaryNode?> - Get summary node by ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshSummary(
String nodeId) → Future< SummaryNode> - Refresh stale summary.
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyClaims(
{required String workspaceId, required String responseText, String? responseId, List< String> ? evidenceIds}) → Future<List< VerifiableClaim> > - Extract and verify claims from text.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited