DeadlineSource class
Describes where deadline data comes from.
Constructors
-
DeadlineSource({required DeadlineSourceType type, String? entityType, String? field, Map<
String, dynamic> ? query, String? scheduleId, String? endpoint}) -
const
-
DeadlineSource.entityField({required String entityType, required String field, Map<
String, dynamic> ? query}) -
Create an entity field deadline source.
factory
- DeadlineSource.external(String endpoint)
-
Create an external deadline source.
factory
- DeadlineSource.schedule(String scheduleId)
-
Create a schedule-based deadline source.
factory
Properties
- endpoint → String?
-
External endpoint URL (for external source).
final
- entityType → String?
-
Entity type (for entityField source).
final
- field → String?
-
Field name on the entity (for entityField source).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
query
→ Map<
String, dynamic> ? -
Query to find entities (for entityField source).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleId → String?
-
Schedule ID (for schedule source).
final
- type → DeadlineSourceType
-
Source type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited