DimensionReductionConfig class
Dimension reduction configuration for high-dimensional signal data.
Signal embeddings (from LLM or feature extraction) can be 768+ dimensions. Dimension reduction improves clustering quality and performance.
Constructors
-
DimensionReductionConfig({required String method, required int targetDimensions, Map<
String, dynamic> ? params}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
Reduction technique: 'pca', 'umap', 'tsne', 'random_projection'.
final
-
params
→ Map<
String, dynamic> ? -
Method-specific parameters (e.g. UMAP nNeighbors, minDist).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetDimensions → int
-
Target dimensionality after reduction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited