EngineResult class
Result of a run / resume.
Constructors
-
EngineResult({required BehaviorRunStatus status, required Map<
String, dynamic> state, String? waitingStepId, String? error}) -
const
Properties
- error → String?
-
Set when status is
failed.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isComplete → bool
-
no setter
- isFailed → bool
-
no setter
- isSuspended → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ Map<
String, dynamic> -
final
- status → BehaviorRunStatus
-
final
- waitingStepId → String?
-
Set when status is
suspended— the step whose guard routed to a suspending outcome (e.g.wait).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited