EventCircuitState class
Circuit breaker state for a handler.
Constructors
- EventCircuitState({required CircuitStatus status, int failures = 0, DateTime? resetAt})
-
const
Properties
- failures → int
-
Number of consecutive failures.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resetAt → DateTime?
-
When the circuit should attempt to reset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CircuitStatus
-
Current circuit status.
final
Methods
-
copyWith(
{CircuitStatus? status, int? failures, DateTime? resetAt}) → EventCircuitState - Create a copy with modifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited