EventMetrics class
Metrics collection for the event system.
Wraps a MetricsCollector to provide event-specific metric recording and an interceptor that can be registered on the EventRouter.
Constructors
- EventMetrics({required MetricsCollector collector})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
metricsInterceptor(
OpsEvent event, Future< void> next()) → Future<void> - Interceptor that captures metrics for each event processed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordDrop(
String eventType) → void - Record an event being dropped.
-
recordPublish(
String eventType) → void - Record a publish event.
-
recordRetry(
String eventType) → void - Record a retry attempt.
-
registerMetrics(
) → void - Register standard event system metrics with the collector.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDlqSize(
int size) → void - Update the DLQ size gauge.
-
updateQueueDepth(
int depth) → void - Update the queue depth gauge.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited