ExecutionFilter class
Filter criteria for listing executions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum number of results to return.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleId → String?
-
Filter by schedule ID.
final
- since → DateTime?
-
Only include executions after this time.
final
- status → String?
-
Filter by execution status.
final
- until → DateTime?
-
Only include executions before this time.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited