ExecutionLogger class
Execution logger with additional methods for pipeline/workflow lifecycle.
Extends Logger with stage lifecycle, gate evaluation, progress tracking, and performance metric methods for observability during execution.
Constructors
-
ExecutionLogger({String name = 'execution', LogLevel minLevel = LogLevel.info, LogSink? sink, Map<
String, dynamic> ? context})
Properties
Methods
-
checkpoint(
String checkpointId, {Object? data, Map< String, dynamic> ? metadata}) → void - Log an execution checkpoint.
-
child(
String childName, {Map< String, dynamic> ? context}) → ExecutionLogger -
Create child logger with additional context.
override
-
debug(
String message, [Map< String, dynamic> ? context]) → void -
Log debug message.
inherited
-
error(
String message, {Object? error, Map< String, dynamic> ? context}) → void -
Log error message.
inherited
-
fatal(
String message, {Object? error, Map< String, dynamic> ? context}) → void -
Log fatal message.
inherited
-
gateEvaluate(
String gateId, bool result, {Map< String, dynamic> ? metadata}) → void - Log a gate evaluation result.
-
info(
String message, [Map< String, dynamic> ? context]) → void -
Log info message.
inherited
-
metric(
String name, double value, {String? unit, Map< String, dynamic> ? metadata}) → void - Log a performance metric.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
progress(
String stageId, {int? current, int? total, double? percent, Map< String, dynamic> ? metadata}) → void - Log execution progress.
-
stageEnd(
String stageId, {Object? result, Map< String, dynamic> ? metadata}) → void - Log the successful end of a stage.
-
stageFail(
String stageId, Object error, {Map< String, dynamic> ? metadata}) → void - Log a stage failure.
-
stageSkip(
String stageId, {String? reason, Map< String, dynamic> ? metadata}) → void - Log a skipped stage.
-
stageStart(
String stageId, {Map< String, dynamic> ? metadata}) → void - Log the start of a stage.
-
toString(
) → String -
A string representation of this object.
inherited
-
trace(
String message, [Map< String, dynamic> ? context]) → void -
Log trace message.
inherited
-
warn(
String message, [Map< String, dynamic> ? context]) → void -
Log warning message.
inherited
-
withContext(
Map< String, dynamic> additionalContext) → ExecutionLogger -
Create a new logger with additional context merged in.
override
-
withTraceId(
String traceId) → ExecutionLogger -
Create a new logger with a trace ID set in context.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited