ExecutionResult class
Result of skill execution.
Constructors
-
ExecutionResult({required bool success, dynamic output, String? error, Map<
String, dynamic> stepResults = const {}, Duration? duration}) -
ExecutionResult.failure(String error, {Map<
String, dynamic> ? stepResults, Duration? duration}) -
Create a failure result.
factory
-
ExecutionResult.success(dynamic output, {Map<
String, dynamic> ? stepResults, Duration? duration}) -
Create a success result.
factory
Properties
- duration → Duration?
-
Execution duration.
final
- error → String?
-
Error message if failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → dynamic
-
Output value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stepResults
→ Map<
String, dynamic> -
Results from each step.
final
- success → bool
-
Whether execution succeeded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited