ExpressionEnginePort class abstract
Engine contract for expression formatting and condition evaluation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adjustTone(
String content, ToneConfig tone, RuntimeProfileContext context) → Future< String> - Adjust tone of content.
-
evaluateCondition(
PolicyCondition condition, AppraisalResult appraisal, RuntimeProfileContext context) → Future< bool> - Evaluate expression policy condition.
-
format(
String content, ExpressionStyle style, RuntimeProfileContext context) → Future< FormattedResponse> - Format content according to style.
-
getHedgingPhrases(
double uncertainty, HedgingConfig? config) → List< String> - Get hedging phrases for uncertainty level.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restructure(
String content, FormatConfig format, RuntimeProfileContext context) → Future< String> - Restructure content format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited