ExpressionResultMetadata class
Metadata about expression evaluation.
Constructors
- ExpressionResultMetadata({required DateTime evaluatedAt, required Object hedgingApplied, String? audienceAdaptation})
-
const
-
ExpressionResultMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- audienceAdaptation → String?
-
Audience adaptation used (if any).
final
- evaluatedAt → DateTime
-
When evaluation was performed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasHedging → bool
-
Whether any hedging was applied.
no setter
- hedgingApplied → Object
-
Hedging information: either a bool (whether hedging was applied)
or a List
final
-
hedgingPhrases
→ List<
String> -
Get hedging phrases if available.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited