ExpressionStyleFormatter class
Formatter that applies expression style to raw content.
This provides more granular control over formatting than the policy evaluator.
Constructors
- ExpressionStyleFormatter()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
{required String content, required ExpressionStyle style, Map< String, double> ? metrics}) → String - Format content according to style.
-
generateStylePrompt(
ExpressionStyle style) → String - Generate style prompt for LLM-based formatting.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited