GateCondition class
Gate condition.
Constructors
-
GateCondition({required ConditionType type, String? metric, String? operator, dynamic value, String? expression, List<
String> ? approvers}) -
const
Properties
-
approvers
→ List<
String> ? -
Required approvers (for approval conditions).
final
- expression → String?
-
Condition expression or configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metric → String?
-
Metric name (for threshold conditions).
final
- operator → String?
-
Comparison operator (for threshold conditions).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ConditionType
-
Condition type.
final
- value → dynamic
-
Target value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited