HealthCheck class
Health check definition.
Constructors
-
HealthCheck({required String id, required String name, String description = '', HealthCheckType type = HealthCheckType.liveness, required Future<
HealthCheckResult> check(), Duration timeout = const Duration(seconds: 5), Duration interval = const Duration(seconds: 30), bool critical = false})
Properties
-
check
→ Future<
HealthCheckResult> Function() -
Check function.
final
- critical → bool
-
Whether this check is critical.
final
- description → String
-
Check description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Check ID.
final
- interval → Duration
-
Interval between checks.
final
- name → String
-
Check name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Timeout for the check.
final
- type → HealthCheckType
-
Check type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited