InMemoryRelationStorage class
In-memory implementation of RelationStoragePort.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- relationCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
deleteRelation(
String relationId) → Future< void> -
Delete relation.
override
-
getRelation(
String relationId) → Future< Relation?> -
Get relation by ID.
override
-
getRelationsForEntity(
String entityId) → Future< List< Relation> > -
Get relations for entity.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryRelations(
RelationQuery query) → Future< List< Relation> > -
Query relations.
override
-
saveRelation(
Relation relation) → Future< void> -
Store relation.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited