KnowledgeConfig class
System-wide configuration.
Constructors
- KnowledgeConfig({String workspaceId = 'default', FactGraphConfig factGraph = const FactGraphConfig(), SkillConfig skill = const SkillConfig(), ProfileConfig profile = const ProfileConfig(), PipelineConfig pipeline = const PipelineConfig(), SchedulerConfig scheduler = const SchedulerConfig(), EventConfig events = const EventConfig(), LoggingConfig logging = const LoggingConfig(), FeatureFlags features = const FeatureFlags(), PhilosophyConfig philosophy = const PhilosophyConfig()})
-
const
Properties
- events → EventConfig
-
Event configuration.
final
- factGraph → FactGraphConfig
-
FactGraph configuration.
final
- features → FeatureFlags
-
Feature flags.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logging → LoggingConfig
-
Logging configuration.
final
- philosophy → PhilosophyConfig
-
Philosophy configuration.
final
- pipeline → PipelineConfig
-
Pipeline configuration.
final
- profile → ProfileConfig
-
Profile configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduler → SchedulerConfig
-
Scheduler configuration.
final
- skill → SkillConfig
-
Skill configuration.
final
- workspaceId → String
-
Workspace identifier.
final
Methods
-
copyWith(
{String? workspaceId, FactGraphConfig? factGraph, SkillConfig? skill, ProfileConfig? profile, PipelineConfig? pipeline, SchedulerConfig? scheduler, EventConfig? events, LoggingConfig? logging, FeatureFlags? features, PhilosophyConfig? philosophy}) → KnowledgeConfig - Create copy with modifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const KnowledgeConfig
- Default configuration.
- development → const KnowledgeConfig
- Development configuration.
- production → const KnowledgeConfig
- Production configuration.