KnowledgeEventBus class
Event bus for knowledge system.
Constructors
- KnowledgeEventBus()
- Create a new event bus.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
KnowledgeEvent> -
Stream of all events.
no setter
Methods
-
close(
) → Future< void> - Close the event bus.
-
emit(
KnowledgeEvent event) → void - Emit an event.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
T extends KnowledgeEvent> () → Stream< T> - Stream filtered by event type.
-
subscribe<
T extends KnowledgeEvent> (void handler(T event)) → StreamSubscription< T> - Subscribe with handler.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited