MeasurementSourceType enum
Types of measurement sources.
Values
- codeAnalysis → const MeasurementSourceType
-
Code analysis tool.
- metricQuery → const MeasurementSourceType
-
Metric query.
- evidenceExtraction → const MeasurementSourceType
-
Evidence extraction.
- manual → const MeasurementSourceType
-
Manual entry.
- computed → const MeasurementSourceType
-
Computed from expression.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → MeasurementSourceType
Constants
-
values
→ const List<
MeasurementSourceType> - A constant List of the values in this enum, in order of their declaration.