PathResult class
Path result for graph traversal.
Constructors
-
PathResult({required List<
String> nodes, required List<String> edges})
Properties
-
edges
→ List<
String> -
Edges in the path.
final
- end → String?
-
End node.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether path is empty.
no setter
- length → int
-
Path length (number of edges).
no setter
-
nodes
→ List<
String> -
Nodes in the path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → String?
-
Start node.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited