Procedure class
A procedure defines the execution steps of a skill.
Constructors
-
Procedure({required String id, required String name, String? description, String? version, List<
Parameter> ? inputs, List<Parameter> ? outputs, required List<Step> steps, List<QualityGate> ? qualityGates, List<String> ? retrieverRefs}) -
const
-
Procedure.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- description → String?
-
Procedure description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Procedure identifier.
final
-
inputs
→ List<
Parameter> ? -
Input parameters.
final
- name → String
-
Procedure name.
final
-
outputs
→ List<
Parameter> ? -
Output parameters.
final
-
qualityGates
→ List<
QualityGate> ? -
Quality gates for validation.
final
-
retrieverRefs
→ List<
String> ? -
Default retrievers for this procedure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
Step> -
Execution steps.
final
- version → String?
-
Procedure version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited