ResolutionError class
Resolution error.
Constructors
-
ResolutionError({required ResolutionErrorType type, required String message, List<
String> packages = const [], List<ConflictPath> ? conflictPaths, List<SuggestedFix> suggestions = const []}) -
const
Properties
-
conflictPaths
→ List<
ConflictPath> ? -
Conflict details (if applicable).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message.
final
-
packages
→ List<
String> -
Packages involved in the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suggestions
→ List<
SuggestedFix> -
Suggested fixes.
final
- type → ResolutionErrorType
-
Error type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited