ScheduleTarget class
Target for a scheduled/triggered action.
Constructors
-
ScheduleTarget({required String kind, required String id, Map<
String, dynamic> parameters = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Target identifier.
final
- kind → String
-
Target kind (e.g.,
workflow,pipeline,runbook).final -
parameters
→ Map<
String, dynamic> -
Target parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited