SkillQuery class
Query for skills.
Constructors
- SkillQuery({String? workspaceId, SkillStatus? status, String? namePattern, int? limit})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Limit results.
final
- namePattern → String?
-
Filter by name pattern.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → SkillStatus?
-
Filter by status.
final
- workspaceId → String?
-
Filter by workspace.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited