SkillResultRetrieval class
Service for retrieving skill results from FactGraph.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getByRunId(
String runId) → Future< SkillRunWithClaims?> - Retrieve a single skill run by ID.
-
getLatestRun(
String skillId, {String? workspaceId}) → Future< SkillRunWithClaims?> - Retrieve the latest run for a skill.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retrieve(
SkillResultQuery query) → Future< List< SkillRunWithClaims> > - Retrieve skill results matching a query.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited