StepExecution class
Tracks individual step execution state.
Constructors
-
StepExecution({required String stepId, required StepExecutionStatus status, DateTime? startedAt, DateTime? completedAt, Duration? duration, Map<
String, dynamic> ? input, Map<String, dynamic> ? output, String? error, List<CheckResult> ? preCheckResults, List<CheckResult> ? postCheckResults}) -
const
Properties
- completedAt → DateTime?
-
When step completed.
final
- duration → Duration?
-
Step execution duration.
final
- error → String?
-
Error message if failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> ? -
Input data for the step.
final
-
output
→ Map<
String, dynamic> ? -
Output data from the step.
final
-
postCheckResults
→ List<
CheckResult> ? -
Post-check results.
final
-
preCheckResults
→ List<
CheckResult> ? -
Pre-check results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime?
-
When step started.
final
- status → StepExecutionStatus
-
Current step status.
final
- stepId → String
-
Step identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited