VersionUnion class
Union of multiple version ranges.
Constructors
-
VersionUnion(List<
VersionRange> ranges)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAny → bool
-
Whether this constraint allows any version.
no setter
- isEmpty → bool
-
Whether this constraint allows no versions.
no setter
-
ranges
→ List<
VersionRange> -
Constituent ranges.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allows(
SemanticVersion version) → bool - Check if a version satisfies this constraint.
-
intersect(
VersionConstraint other) → VersionConstraint - Intersect with another constraint.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
union(
VersionConstraint other) → VersionConstraint - Union with another constraint.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited