VersionedGraphStorage class
Graph storage with versioning support.
- Implemented types
Constructors
- VersionedGraphStorage(GraphStorage _baseStorage)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String id) → Future< bool> -
Delete a graph.
override
-
exists(
String id) → Future< bool> -
Check if a graph exists.
override
-
getVersions(
String id) → Future< List< int> > - Get all versions of a graph.
-
listIds(
) → Future< List< String> > -
List all graph IDs.
override
-
load(
String id) → Future< FactGraph?> -
Load a graph by ID.
override
-
loadVersion(
String id, int version) → Future< FactGraph?> - Load a specific version.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
FactGraph graph) → Future< void> -
Save a graph.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited